@@ -1,11 +1,19 @@
 from conductor.client.automator.task_handler import TaskHandler
 from conductor.client.configuration.configuration import Configuration
+from conductor.client.configuration.settings.authentication_settings import AuthenticationSettings
 from conductor.client.worker.sample.faulty_execution_worker import FaultyExecutionWorker
 from conductor.client.worker.sample.simple_python_worker import SimplePythonWorker
 
 
 def main():
-    configuration = Configuration(debug=True)
+    configuration = Configuration(
+        base_url='https://play.orkes.io',
+        debug=True,
+        authentication_settings=AuthenticationSettings(
+            key_id='id',
+            key_secret='secret'
+        )
+    )
     task_definition_name = 'python_task_example'
     workers = [
         FaultyExecutionWorker(task_definition_name),
